from distutils.core import setup
setup(
  name = 'lydia',
  packages = ['lydia'],
  version = '0.1.1',
  description = 'A high level companion for data science',
  author = 'Mycchaka Kleinbort',
  author_email = 'mkleinbort@gmail.com',
  url = 'https://github.com/mkleinbort/lydia',
  download_url = 'https://github.com/mkleinbort/lydia/archive/0.1.1.tar.gz',
  keywords = ['data science', 'pandas', 'python', 'modeling', 'jupyter'],
  classifiers = [],
)
